==> kafka-streams-0.11.0.0-cp1-test-sources.jar: org/apache/kafka/test/MockChangelogReader.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.test;

import org.apache.kafka.common.TopicPartition;
import org.apache.kafka.streams.processor.internals.ChangelogReader;
import org.apache.kafka.streams.processor.internals.StateRestorer;

import java.util.Collections;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

public class MockChangelogReader implements ChangelogReader {
    private final Set<TopicPartition> registered = new HashSet<>();

    @Override
    public void validatePartitionExists(final TopicPartition topicPartition, final String storeName) {

    }

    @Override
    public void register(final StateRestorer restorationInfo) {
        registered.add(restorationInfo.partition());
    }

    @Override
    public void restore() {

    }

    @Override
    public Map<TopicPartition, Long> restoredOffsets() {
        return Collections.emptyMap();
    }

    public boolean wasRegistered(final TopicPartition partition) {
        return registered.contains(partition);
    }
}

==> kafka-streams-0.11.0.1-cp1-test-sources.jar: org/apache/kafka/test/MockChangelogReader.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.test;

import org.apache.kafka.common.TopicPartition;
import org.apache.kafka.streams.processor.internals.ChangelogReader;
import org.apache.kafka.streams.processor.internals.StateRestorer;

import java.util.Collection;
import java.util.Collections;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

public class MockChangelogReader implements ChangelogReader {
    private final Set<TopicPartition> registered = new HashSet<>();

    @Override
    public void register(final StateRestorer restorer) {
        registered.add(restorer.partition());
    }

    @Override
    public Collection<TopicPartition> restore() {
        return registered;
    }

    @Override
    public Map<TopicPartition, Long> restoredOffsets() {
        return Collections.emptyMap();
    }

    @Override
    public void reset() {
        registered.clear();
    }

    public boolean wasRegistered(final TopicPartition partition) {
        return registered.contains(partition);
    }
}
